#!/bin/bash
# Copyright (c) 2019 Achim D. Brucker
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice, this
#
# * Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# SPDX-License-Identifier: BSD-2-Clause

set -e 

VERSION=${1:-2019}
SESSIONS=${2:-"HOL"}
DOCKERUID=${3:-`id -u`}

LATEST="2019"

# Generate base image
docker build -t logicalhacking/lh-docker-isabelle:debian4isabelle debian4isabelle

# Generate Isabelle image
ISA_URL="https://isabelle.in.tum.de/website-Isabelle"$VERSION"/dist/Isabelle"$VERSION"_linux.tar.gz"
if [ "$LATEST" -eq "$VERSION" ]; then
  AFP_URL="https://www.isa-afp.org/release/"
  AFP_TAR=`w3m -dump  $AFP_URL | grep "afp-[0-9]" | awk -e '{print $3}' | sort -r | head -1`
else
  AFP_URL="https://sourceforge.net/projects/afp/files/afp-Isabelle$VERSION/"
  AFP_TAR=`w3m -dump  $AFP_URL | grep ^afp- | head -1 | awk -e '{print $1}'`
fi

for url in $ISA_URL $AFP_URL/$AFP_TAR; do
  if curl --output /dev/null --silent --head --fail "$url"; then
    echo "URL exists: $url"
  else
    echo "URL does not exist: $url"
    exit 1
  fi
done

docker build -t logicalhacking/lh-docker-isabelle:isabelle$VERSION isabelle \
             --build-arg uid=$DOCKERUID \
             --build-arg sessions=$SESSIONS \
             --build-arg isabelle=$ISA_URL \
             --build-arg afp=$AFP_URL/$AFP_TAR
